==> hprose-java-1.6.0-sources.jar: hprose/server/TcpContext.java <==
/**********************************************************\
|                                                          |
|                          hprose                          |
|                                                          |
| Official WebSite: http://www.hprose.com/                 |
|                   http://www.hprose.org/                 |
|                                                          |
\**********************************************************/
/**********************************************************\
 *                                                        *
 * TcpContext.java                                        *
 *                                                        *
 * tcp context class for Java.                            *
 *                                                        *
 * LastModified: Apr 19, 2015                             *
 * Author: Ma Bingyao <andot@hprose.com>                  *
 *                                                        *
\**********************************************************/
package hprose.server;

import hprose.common.HproseContext;
import java.net.Socket;
import java.nio.channels.SocketChannel;

public class TcpContext extends HproseContext {
    private final SocketChannel socketChannel;
    public TcpContext(SocketChannel socketChannel) {
        this.socketChannel = socketChannel;
    }

    public SocketChannel getSocketChannel() {
        return socketChannel;
    }

    public Socket getSocket() {
        return socketChannel.socket();
    }
}

==> hprose-java-2.0.38-sources.jar: hprose/server/TcpContext.java <==
/**********************************************************\
|                                                          |
|                          hprose                          |
|                                                          |
| Official WebSite: http://www.hprose.com/                 |
|                   http://www.hprose.org/                 |
|                                                          |
\**********************************************************/
/**********************************************************\
 *                                                        *
 * TcpContext.java                                        *
 *                                                        *
 * tcp context class for Java.                            *
 *                                                        *
 * LastModified: Apr 26, 2016                             *
 * Author: Ma Bingyao <andot@hprose.com>                  *
 *                                                        *
\**********************************************************/
package hprose.server;

import java.net.Socket;
import java.nio.channels.SocketChannel;

public class TcpContext extends ServiceContext {
    private final SocketChannel socketChannel;
    public TcpContext(HproseClients clients,
                      SocketChannel socketChannel) {
        super(clients);
        this.socketChannel = socketChannel;
    }

    public SocketChannel getSocketChannel() {
        return socketChannel;
    }

    public Socket getSocket() {
        return socketChannel.socket();
    }
}
